# Task 5 - Create the python package

Convert your previous application to the python package. Add README.md and describe how to use this package.

Resources:
Packaging Python Projects https://packaging.python.org/tutorials/packaging-projects/


-- Added by Vadym Serdiuk 14.07.2022. Than